<?php
/**
 * Chinese Traditional language file
 *
 * @author Li-Jiun Huang <ljhuang.tw@gmail.com>
 * @author http://www.chinese-tools.com/tools/converter-simptrad.html
 * @author Wayne San <waynesan@zerozone.tw>
 * @author Li-Jiun Huang <ljhuang.tw@gmai.com>
 * @author Cheng-Wei Chien <e.cwchien@gmail.com>
 * @author Danny Lin <danny0838@pchome.com.tw>
 * @author Shuo-Ting Jian <shoting@gmail.com>
 * @author syaoranhinata@gmail.com
 * @author Ichirou Uchiki <syaoranhinata@gmail.com>
 */
$lang['menu']                  = '還原管理';
$lang['filter']                = '搜索包含垃圾訊息的頁面';
$lang['revert']                = '還原選取的頁面';
$lang['reverted']              = '%s 已還原成版本 %s';
$lang['removed']               = '%s 已移除';
$lang['revstart']              = '已開始還原操作。有可能需要很長時間。如果程式執行逾時，請嘗試分次還原少量內容。';
$lang['revstop']               = '還原程序已完成。';
$lang['note1']                 = '注意：搜尋區分大小寫';
$lang['note2']                 = '注意：我們將把此頁面還原作最後一個不含垃圾訊息 <i>%s</i> 的版本。';
